package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut


__DATA__
M?T5,1@("`0`````````````#`!8````!````````(U``````````0```````
M`+%X``````!``#@`"`!``!<`%@````8````%`````````$``````````0```
M``````!``````````<`````````!P``````````(`````P````0````````"
M``````````(``````````@``````````&``````````8``````````$````!
M````!0```````````````````````````````````````*#4````````H-0`
M```````0``````$````&````````J[@```````"[N````````+NX````````
M!/@````````58````````!```````@````8```````"KX````````+O@````
M````N^`````````!H`````````&@``````````AD=.50````!````````)N,
M````````FXP```````";C`````````"\`````````+P`````````!&1TY5$`
M```&````````````````````````````````````````````````````````
M```````09'3E4@````0```````"KN````````+NX````````N[@````````$
M2`````````1(``````````$O;&EB+VQD+6UU<VPM<S,Y,'@N<V\N,0`````1
M````3`````(````'201`"0@`A9KH`(2*012.2`````````!,````4````%0`
M``!5````6@```%L```!<`````````%X``````````````%\```!@````80``
M````````?)I_:@[OT^HM1][.']_%;[:;Q2X.\8VX?-1DU`[D_R$<6''98&RA
M^BP_Y<)OBP&R`<9'XGR2X[O2/,-59LRO9]-P!XCLU45#[=MB,YN<J7\*`J?A
M2?O@HP```````````````````````````````````````````P``!P``````
M`!DX```````````````,$@````````````````````````````''$@``````
M```````````````````````4$0````````````````````````````'M$0``
M``````````````````````````%I$@`````````````````````````````;
M$@````````````````````````````&F$@``````````````````````````
M```C$@`````````````````````````````J$@``````````````````````
M``````'Z$@````````````````````````````&R$@``````````````````
M```````````S(`````````````````````````````-"(0``````````````
M``````````````!+$@````````````````````````````!1$@``````````
M``````````````````,($@````````````````````````````+Y$@``````
M``````````````````````)_$@````````````````````````````!8$@``
M``````````````````````````(@$@````````````````````````````!?
M$@````````````````````````````*T$@``````````````````````````
M``!F$@````````````````````````````!N(```````````````````````
M``````""$@````````````````````````````*=$@``````````````````
M``````````"*$@````````````````````````````"0$@``````````````
M``````````````"9(`````````````````````````````+R$@``````````
M``````````````````"U$@````````````````````````````"Z$@``````
M``````````````````````(+$0````````````````````````````*[$@``
M``````````````````````````)-$@````````````````````````````,8
M$@````````````````````````````(_$@``````````````````````````
M``.<$@````````````````````````````+&$0``````````````````````
M``````-!$0````````````````````````````)Q$@``````````````````
M``````````,N$@````````````````````````````-#$0``````````````
M``````````````#!$@````````````````````````````,F$@``````````
M``````````````````%W$@````````````````````````````#*(@``````
M``````````````````````#9(`````````````````````````````#O$@``
M``````````````````````````+J$@````````````````````````````)=
M$@````````````````````````````#T$@``````````````````````````
M``#Z(`````````````````````````````*H$@``````````````````````
M``````$4$@````````````````````````````&7$@``````````````````
M``````````$9$@````````````````````````````*-$@``````````````
M``````````````&&$@````````````````````````````$?$@``````````
M``````````````````$P$@````````````````````````````(;$@``````
M``````````````````````"+$@````````````````````````````(L$@``
M``````````````````````````)F$@````````````````````````````,?
M$@````````````````````````````$V$@``````````````````````````
M``,0$@````````````````````````````%*$@``````````````````````
M``````(6$@````````````````````````````'5$@``````````````````
M``````````%1$@````````````````````````````-`(0``````````````
M``````````````%B$@````````````````````````````,[$@``"0``````
M`"$``````````DP```'G$@``"@```````%L```````````(```/>$@``"0``
M`````$Q`````````"C(```14$@``"0```````%HX`````````&X```.[$@``
M"0```````$5P``````````8```/M$@``!P```````!DX``````````(```0!
M$@``"0```````%9X`````````[P```1'$@``"0```````$5X`````````@@`
M``-2$```%````````,"P``````````````/,$@``"0```````$M`````````
M`/X```/K$@``"0```````$.X`````````#P```/S$@``"0```````$J(````
M`````'(```0A$@``"0```````$>``````````"(```->$```%````````-$8
M``````````````.!$@``"0```````".``````````#0```0N$@``"0``````
M`$>H`````````2P```07$0``$P```````,"H``````````@```-+$```$P``
M`````,"P``````````````-7$@``"0```````"-0``````````````.*$@``
M"0```````$L``````````#H```.E$@``"0```````$18`````````1@```0Z
M$@``"0```````$C8`````````:X`;&EB<&5R;"YS;P!O<&5N9&ER`'-T9&5R
M<@!R96%L;&]C`&%C8V5S<P!S;G!R:6YT9@!?7V1E<F5G:7-T97)?9G)A;65?
M:6YF;P!L<V5E:P!G971P:60`;65M<V5T`'5N;&EN:P!M96UM;W9E`%]*=E]2
M96=I<W1E<D-L87-S97,`<W1R;F-M<`!L<W1A=`!C;&]S961I<@!?251-7V1E
M<F5G:7-T97)434-L;VYE5&%B;&4`;W!E;@!S=')S='(`<F5A9&QI;FL`7U]C
M>&%?9FEN86QI>F4`7U]R96=I<W1E<E]F<F%M95]I;F9O`&5X:70`8VQO<V4`
M7TE435]R96=I<W1E<E1-0VQO;F5486)L90!R96%D`')M9&ER`%]?97)R;F]?
M;&]C871I;VX`;6MD:7(`<'1H<F5A9%]G971S<&5C:69I8P!M96UC<'D`7U]S
M=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I
M;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T
M7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S
M=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA
M9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O
M<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?
M<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O
M;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P
M97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F,N;75S;"US,SDP>"YS;RXQ
M`&9P<FEN=&8`<W1R9'5P`'!T:')E861?871F;W)K`')E861D:7(`<W!R:6YT
M9@!S=')C:'(`<W1R=&]K`'-T<FYC<'D`7U]L:6)C7W-T87)T7VUA:6X`7U]?
M96YV:7)O;@!?961A=&$`7U]B<W-?<W1A<G0`7V5N9``O=7-R+VQI8B]P97)L
M-2]C;W)E7W!E<FPO0T]210!?<W1A<G1?8P!G971?=7-E<FYA;65?9G)O;5]G
M971P=W5I9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V-U<G)E;G1?97AE
M8P!P87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT;7!D:7(`>'-?:6YI=`!P87)?
M96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!M>5]P87)?<&P`<&%R
M7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]I;FET7V5N=@!P87)?9FEN9'!R
M;V<`<&%R7V-L96%N=7``````````OW@`````````#````````"$`````````
MOY``````````#````````%L`````````O[``````````#````````!DX````
M````P```````````#````````,``````````P`@`````````#````````%S.
M````````P!``````````#````````%RV````````P!@`````````#```````
M`%R^````````P"``````````#````````%SD````````P"@`````````#```
M`````%S,````````P#``````````#````````%S>````````P$``````````
M#````````%W4````````P$@`````````#````````%MX````````P%@`````
M````#````````%QZ````````P&``````````#````````%Q^````````P&@`
M````````#````````%W:````````P'``````````#````````%O*````````
MP'@`````````#````````%WB````````P(@`````````#````````%WF````
M````P)``````````#````````%WL````````P*@`````````#````````%Z.
M````````OX`````$````"@``````````````````OX@````%````"@``````
M````````````OY@````-````"@``````````````````OZ`````9````"@``
M````````````````OZ@````>````"@``````````````````O[@````B````
M"@``````````````````O\`````H````"@``````````````````O\@````L
M````"@``````````````````O]`````P````"@``````````````````O]@`
M```Q````"@``````````````````O^`````V````"@``````````````````
MO^@````[````"@``````````````````O_`````\````"@``````````````
M````O_@```!!````"@``````````````````O9@````"````"P``````````
M````````O:`````#````"P``````````````````O:@````&````"P``````
M````````````O;`````'````"P``````````````````O;@````(````"P``
M````````````````O<`````)````"P``````````````````O<@````*````
M"P``````````````````O=`````+````"P``````````````````O=@````,
M````"P``````````````````O>`````-````"P``````````````````O>@`
M```/````"P``````````````````O?`````0````"P``````````````````
MO?@````1````"P``````````````````O@`````2````"P``````````````
M````O@@````3````"P``````````````````OA`````4````"P``````````
M````````OA@````5````"P``````````````````OB`````6````"P``````
M````````````OB@````7````"P``````````````````OC`````8````"P``
M````````````````OC@````:````"P``````````````````OD`````;````
M"P``````````````````OD@````<````"P``````````````````OE`````=
M````"P``````````````````OE@````?````"P``````````````````OF``
M```@````"P``````````````````OF@````A````"P``````````````````
MOG`````C````"P``````````````````OG@````D````"P``````````````
M````OH`````E````"P``````````````````OH@````F````"P``````````
M````````OI`````G````"P``````````````````OI@````J````"P``````
M````````````OJ`````K````"P``````````````````OJ@````M````"P``
M````````````````OK`````N````"P``````````````````OK@````O````
M"P``````````````````OL`````P````"P``````````````````OL@````Q
M````"P``````````````````OM`````R````"P``````````````````OM@`
M```S````"P``````````````````ON`````T````"P``````````````````
MON@````U````"P``````````````````OO`````W````"P``````````````
M````OO@````X````"P``````````````````OP`````Y````"P``````````
M````````OP@````Z````"P``````````````````OQ`````]````"P``````
M````````````OQ@````^````"P``````````````````OR`````_````"P``
M````````````````OR@```!`````"P``````````````````OS````!"````
M"P``````````````````OS@```!#````"P``````````````````OT````!$
M````"P``````````````````OT@```!%````"P``````````````````OU``
M``!&````"P``````````````````OU@```!'````"P``````````````````
MOV````!(````"P``````````````````OV@```!)````"P``````````````
M````OW````!+````"P``````````Z^_P<``DN00`#Z?[_V#C`/```"3`Y0``
M!=K`Y0``(*OK[_$0``0'_N,0\#@`),`0``!2#=('\#`0".,0$!``!`?Q!P`'
M``<`P!```%(,XQ`0```$!_$-$.,0$`P`%,#T____Y0````#`$```4@#C$!``
M``0'\0T0XQ`0#``4P/3____5````&,`0``!1].,0$```!`?Q#1#C$!`,`!3`
M]/___\4````PP!```%'HXQ`0```$!_$-$.,0$`P`%,#T____M0```$C`$```
M4=SC$!````0'\0T0XQ`0#``4P/3___^E````8,`0``!1T.,0$```!`?Q#1#C
M$!`,`!3`]/___Y4```!XP!```%'$XQ`0```$!_$-$.,0$`P`%,#T____A0``
M`)#`$```4;CC$!````0'\0T0XQ`0#``4P/3___]U````J,`0``!1K.,0$```
M!`?Q#1#C$!`,`!3`]/___V4```#`P!```%&@XQ`0```$!_$-$.,0$`P`%,#T
M____50```-C`$```493C$!````0'\0T0XQ`0#``4P/3___]%````\,`0``!1
MB.,0$```!`?Q#1#C$!`,`!3`]/___S4```$(P!```%%\XQ`0```$!_$-$.,0
M$`P`%,#T____)0```2#`$```47#C$!````0'\0T0XQ`0#``4P/3___\5```!
M.,`0``!19.,0$```!`?Q#1#C$!`,`!3`]/___P4```%0P!```%%8XQ`0```$
M!_$-$.,0$`P`%,#T___^]0```6C`$```44SC$!````0'\0T0XQ`0#``4P/3_
M__[E```!@,`0``!10.,0$```!`?Q#1#C$!`,`!3`]/___M4```&8P!```%$T
MXQ`0```$!_$-$.,0$`P`%,#T___^Q0```;#`$```42CC$!````0'\0T0XQ`0
M#``4P/3___ZU```!R,`0``!1'.,0$```!`?Q#1#C$!`,`!3`]/___J4```'@
MP!```%$0XQ`0```$!_$-$.,0$`P`%,#T___^E0```?C`$```403C$!````0'
M\0T0XQ`0#``4P/3___Z%```"$,`0``!0^.,0$```!`?Q#1#C$!`,`!3`]/__
M_G4```(HP!```%#LXQ`0```$!_$-$.,0$`P`%,#T___^90```D#`$```4.#C
M$!````0'\0T0XQ`0#``4P/3___Y5```"6,`0``!0U.,0$```!`?Q#1#C$!`,
M`!3`]/___D4```)PP!```%#(XQ`0```$!_$-$.,0$`P`%,#T___^-0```HC`
M$```4+SC$!````0'\0T0XQ`0#``4P/3___XE```"H,`0``!0L.,0$```!`?Q
M#1#C$!`,`!3`]/___A4```*XP!```%"DXQ`0```$!_$-$.,0$`P`%,#T___^
M!0```M#`$```4)CC$!````0'\0T0XQ`0#``4P/3___WU```"Z,`0``!0C.,0
M$```!`?Q#1#C$!`,`!3`]/___>4```,`P!```%"`XQ`0```$!_$-$.,0$`P`
M%,#T___]U0```QC`$```4'3C$!````0'\0T0XQ`0#``4P/3___W%```#,,`0
M``!0:.,0$```!`?Q#1#C$!`,`!3`]/___;4```-(P!```%!<XQ`0```$!_$-
M$.,0$`P`%,#T___]I0```V#`$```4%#C$!````0'\0T0XQ`0#``4P/3___V5
M```#>,`0``!01.,0$```!`?Q#1#C$!`,`!3`]/___84```.0P!```%`XXQ`0
M```$!_$-$.,0$`P`%,#T___]=0```ZC`$```4"SC$!````0'\0T0XQ`0#``4
MP/3___UE```#P,`0``!0(.,0$```!`?Q#1#C$!`,`!3`]/___54```/8P!``
M`%`4XQ`0```$!_$-$.,0$`P`%,#T___]10```_#`$```4`CC$!````0'\0T0
MXQ`0#``4P/3___TU```$",`0``!/_.,0$```!`?Q#1#C$!`,`!3`]/___24`
M``0@P!```$_PXQ`0```$!_$-$.,0$`P`%,#T___]%0``!#C`$```3^3C$!``
M``0'\0T0XQ`0#``4P/3___T%```$4,`0``!/V.,0$```!`?Q#1#C$!`,`!3`
M]/___/4```1HP!```$_,XQ`0```$!_$-$.,0$`P`%,#T___\Y0``!(#`$```
M3\#C$!````0'\0T0XQ`0#``4P/3___S5```$F,`0``!/M.,0$```!`?Q#1#C
M$!`,`!3`]/___,4```2PP!```$^HXQ`0```$!_$-$.,0$`P`%,#T___\M0``
M!,C`$```3YSC$!````0'\0T0XQ`0#``4P/3___RE```$X,`0``!/D.,0$```
M!`?Q#1#C$!`,`!3`]/___)4```3XP!```$^$XQ`0```$!_$-$.,0$`P`%,#T
M___\A0``!1#`$```3WCC$!````0'\0T0XQ`0#``4P/3___QU```%*,`0``!/
M;.,0$```!`?Q#1#C$!`,`!3`]/___&4```5`P!```$]@XQ`0```$!_$-$.,0
M$`P`%,#T___\50``!5C`$```3U3C$!````0'\0T0XQ`0#``4P/3___Q%```%
M<,`0``!/2.,0$```!`?Q#1#C$!`,`!3`]/___#4```6(ZV_P,``DP-```!TM
MX_#_2/]QXS#PJ``DXT#PH``D4"#PM$%`\*!!,/"H02#PM,#E___^:<1(``!/
M8L0H``!/6[D$`#3`Y?___.[$&```3Q^5`!``IW0`'L#E___]Q,0K``!7V>PF
M``@`?*<I``'`Y?___GG`Y?___M;$&```3Q_C(!```!;`Y?___TV2`"CUQ+@`
M`$\4XR"P```6P.7___]"E@(D\N,@L```%L#E____.E@0\+26`23R["$`!0#8
MXQ#0```$N10`(NPA``S`9<0X``!.^,`@```=P\#E___\4NLB``,`#<#E___^
M?.,P\*@`!.,0,```!.,0(```),`0```>0^,0(`@`),08``!/3N,0(!``),`0
M```>.>,0(!@`)%A`\+3`$```5VP21.5,$```!*<8``&Y\B`4Q"L``%==03`P
M"*<(``&G%@!L[!0`!`#8N10`$>L1``,`#>,1+_C_<;D$`%+E2!````"G2@`#
MIVD``+D4`$3`,```$+[$*```5T?`Y?___,P8LNPF``H`?L0H``!7/<#E___^
M`ABRQ"@``%<VP.7___UKP"```!RSP.4```W!["8`(@!\P!```%<CXQ`0```"
MIW0`"\`@```<>L#E```-L,0K``!7%<`0``!7$N,0$````J>$``C$*```5PK`
MY0``&Y_$*```5PC`Y?___KW`Y?__^UJY%``KXT#Q*``$ZV_PZ``$!_3L4``$
M`-CCL#````2Y%`!5IPH``>M5``,`#:<[``CCM2_X_R2G]/^"!P<'![D$`"_`
M,````!+C,#```!BG^_]@IPD``.,`\```),#T````"0<'!P<``)AH!P<'!^MO
M\#``).,P(`0`%./P_UC_<4%`(`CE2/"@``#`8```&[+`4/__^LO`(/___JS`
MY?___/D'!P<'P!```$Y\P"```$YY01`0![D)`!+L'``*#GW$&```3>OL&``$
M`'P'\0?^!P<'!P<'P#```$YDP!```$YAN>D0$^L1``,`"NLQ`#\`#+D(`#'K
M,P`!``KL.``-`'S$&```3>;L&``'`'S`(```3D@'\0?^!P<'!P<'P!```$Y`
ME0`0``=^ZZ_P4``DP!```$W'X_#_8/]QXQ`0```"IX0`",0H``!-U,#E___\
MX<"P``!+LL"@``!+L[D)`*OKJ@`#``JGJ___Q!@``$X=[*$`("!EP.7___^7
MP!```$V$XQ`0```"IX0`",`@```[U,#E___Z_<`0``!.`N-`\1``!)(!$`#K
MK_#P``0']*<;``'$&P``3?CK$0`#``WC$;````0-X:?T_]'K[_!P`"3C\/]@
M_W'C0/$0``3K[_$0``0']`<'!P<'!^OO\'``),`0``!-:>/P_V#_<>,0$```
M`J>$``O`,```3=+`(```.Y/`Y?___(S`(```2U7C$"````*GA``)Q!@``$TQ
M[!@`!`!\#>'K[_$0``3`]/___TOK[_!P`"3C\/]@_W'C0/$0``3K[_$0``0'
M]`<'!P<'![)/`!#K$0`@``VR3P`1ZV_P,``DIUD`"./P_-#_<=('\R@0*$&@
M(#A!$/"HI[D``+D$`#'C2Z````3K!``@``SC`#```"3`2@````#C0#`(`"2G
MNP`(ISL`$*=7_^U!0/*HXS`0:``$XS`00`""XS`0$`""XS`0``""[%,@OV%5
M[%,@/@%6XU`0@``DIQL`".Q!_^E@9.,0\*@`!,(:6H)YF>,0("``".,P(```
M!..`(!``!.,`(`@`!.-0(!@`!.RC(+]E5>QP(+]^5>RC(#H%5NQP("$>5KD(
M`*&YYW"XN>=0&+F``+.Y@``0N8(`N+F"`!7LTR"_?E6Y"`"A[-,@(1Y6[$H@
MOP!5XQ#PL``$N8``K<(:6H)YF>MD``(`#+D(`!7L9"`A'E:Y"``;Z[0`&P`,
M[+0@.@56N0@`L>R;(+\`5;F``+:G&?__N><0%*=)__^Y@``7N>=`2;F!`!JY
M@`!-XZ#PN``$N8$`2\*J6H)YF>.P\,``!+D(`*C"NEJ">9FY"`"AN0@`>[D(
M`'3K&0`;``SL&2`Z!5:Y"``:[*$@OP!5ZTH`&P`,[$H@.@56N0@`1^MY``(`
M#.QY("$>5KF``!>GF?__N>>0FKF``):Y@0"1XQ#PR``$PAI:@GF9N0@`T;D(
M`-GLM""_`%7KFP`;``SLFR`Z!5:Y"`"=Z]H``@`,[-H@(1Y6N8``3:>I__^Y
MYZ"KN8``I[F!`*3C0/#0``3"2EJ">9FY"`!DN0@`:NP9(+\`5>NA`!L`#.RA
M(#H%5KD(`*;K:P`"``SL:R`A'E:Y@`"6I[G__[GGL+&Y@`"]N8$`N>.0\-@`
M!,*:6H)YF>Q*(+\`5;D(`'GKD0`"``SLD2`A'E:Y@`"IN0@`>Z<9__^YYQ`4
MN8``%KF!`!KCH/#@``3"JEJ">9FY"`#:N0@`T>NT`!L`#.RT(#H%5KD(`+?L
M>R"_`%7K%P`;``SL%R`Z!5:Y"``=Z]0``@`,[-0@(1Y6N8``O:=)__^YYT!'
MN8``2;F!`$OCL/#H``3"NEJ">9FY"`!KN0@`9.RA(+\`5>M*`!L`#.Q*(#H%
M5KD(`$;K9P`"``SL9R`A'E:Y@``6IWG__[GG<'JY@`!]N8$`<>,0\/``!,(:
M6H)YF;D(`)&Y"`"7[+0@OP!5ZWL`&P`,['L@.@56N0@`>>N:``(`#.R:("$>
M5KF``$FGJ?__N>>@J[F``*:Y@0"DXT#P^``$PDI:@GF9N0@`U+D(`-KL%R"_
M`%7KH0`;``SLH2`Z!5:Y"`"MZ]L``@`,[-L@(1Y6N8``?:>Y__^YY["QN8``
MN;F!`+?C</$```3">EJ">9GL2B"_`%6Y"`!GZW$``@`,['$@(1Y6N8``I[D(
M`&NG&?__N><0%+F``!VY@0`:XZ#Q"``$PJI:@GF9N0@`FKD(`)'KM``;``SL
MM"`Z!5:Y"`"V[&L@OP!5ZQ8`&P`,[!8@.@56N0@`&>N4``(`#.R4("$>5KF`
M`+FG2?__N>=`1KF``$>Y@0!+X[#Q$``$PKI:@GF9N0@`V[D(`-3LH2"_`%7K
M2@`;``SL2B`Z!5:Y"`!-Z]8``@`,[-8@(1Y6N8``':=I__^YYV!JN8``:;F!
M`&'C$/$8``3"&EJ">9FY"`!QN0@`=NRT(+\`5>MK`!L`#.QK(#H%5KD(`&?K
M>@`"``SL>B`A'E:Y@`!'IZG__[GGH*NY@`"MN8$`I.-`\2``!,)*6H)YF;D(
M`)2Y"`":[!8@OP!5ZZ$`&P`,[*$@.@56N0@`J>N;``(`#.R;("$>5KF``&FG
MN?__N>>PL;F``+>Y@0"VXV#Q*``$PFI:@GF9N0@`UKD(`-OL2B"_`%7KM``;
M``SLM"`Z!5:Y"`"]Z]$``@`,[-$@(1Y6N8``K:<9__^YYQ`4N8``&;F!`!KC
MH/$P``3"JEJ">9FY"`!ZN0@`<>QK(+\`5>L6`!L`#.P6(#H%5KD(`!?K=``"
M``SL="`A'E:G2?__N8``M[GG0$:Y@`!-N8$`2^RA(+\`5>.P\3@`!,*Z6H)Y
MF;D(`)NY"`"4ZTH`&P`,[$H@.@56N0@`2>-`\*``).R4(+\`5>NV`!X`#:=)
M___K9@`"``RYYT!*N8``1[F!`+;L:R"_`%6Y@``6N8$`%.-`\4``!,)*6H)Y
MF;D(`-3K2@`>``WKJ@`"``RY@0"DN8(`NN-`\*``!+F"`$OCL/%(``3"NF[9
MZZ&Y"`![Z[D`'@`-N0@`T>L9`!L`#.P9(#H%5NN9``(`#+D(`!VY@0";N>>0
MNKF"`+'LT2"_`%6Y&@!TXQ#Q4``$N00`1\(:;MGKH;D(`!:Y&@`;Z[T`'@`-
MZWT`&P`,['T@.@56Z]T``@`,N0@`=+F!`-OL1R"_`%7CL/%8``3"NF[9ZZ&Y
M&@"ZN>?0J;F"`'JY&@"WZW0`'@`-ZV0`&P`,[&0@.@56ZT0``@`,N8$`1^-P
M\6``!,)Z;MGKH;D:`'FY"`!AN00`J^P6(+\`5;D$`)>YYT!]N8(`9[D:`);K
ML0`;``RY!`!Y[+$@.@56N0@`NNRK(+\`5>N:`!L`#.R:(#H%5NMA`!X`#;D(
M`)?L>2"_`%7K$0`"``RY@0`6XV#Q:``$PFINV>NAN1H`;;GG$-2Y@@"]Z]H`
M'@`-ZZH``@`,N8$`K>/0\7``!,+:;MGKH;D:`-2Y!`!-N>>@T;F"`)WKUP`>
M``VY&@!KZ[<`&P`,[+<@.@56ZW<``@`,N8$`?>/0\7@`!,+:;MGKH;D:`-&Y
M!``=N>=PVKD(`+:Y&@!)[&L@OP!5N8(`O>O6`!X`#;D$`)3K1@`;``SL1B`Z
M!5;K9@`"``RY@0!MX]#Q@``$PMINV>NAN1H`VKD$`*VYYV#7N0@`2;D:`!OL
ME""_`%6Y@@!-Z]D`'@`-N00`L>L9`!L`#.P9(#H%5NN9``(`#+F!`)WCT/&(
M``3"VF[9ZZ&Y&@#7N00`?;GGD-:Y"``;[+$@OP!5N8(`'>O;`!X`#;D:`*3K
M2P`;``SL2R`Z!5;KNP`"``RY@0"]X]#QD``$PMINV>NAN1H`UKD$`&VYY[#9
MN0@`2NRD(+\`5;F"`$WKV@`>``VY&@!QZQH`&P`,[!H@.@56ZZH``@`,N8$`
MK>/0\9@`!,+:;MGKH;D:`-FY!`"=N>>@V[D(`!?L<2"_`%6Y@@`=Z]<`'@`-
MN1H`9.M'`!L`#.Q'(#H%5NMW``(`#+F!`'WCT/&@``3"VF[9ZZ&Y&@#;N00`
MO;GG<-JY"`!&[&0@OP!5N8(`3>O6`!X`#;D:`)'K%@`;``SL%B`Z!5;K9@`"
M``RY@0!MX]#QJ``$PMINV>NAN1H`VKD$`*VYYV#7N0@`&>R1(+\`5;F"`!WK
MV0`>``VY&@"TZTD`&P`,[$D@.@56ZYD``@`,N8$`G>/0\;``!,+:;MGKH;D:
M`->Y!`!]N>>0UKD(`$OLM""_`%6Y@@!-Z]L`'@`-N1H`H>L;`!L`#.P;(#H%
M5NN[``(`#+F!`+WCT/&X``3"VF[9ZZ&Y&@#6N00`;;GGL-FY"``:[*$@OP!5
MN8(`'>O:`!X`#;D:`'3K2@`;``SL2B`Z!5;KJ@`"``RY@0"MX]#QP``$PMIN
MV>NAN1H`V;D$`)VYYZ#;N0@`1^QT(+\`5;F"`$WKUP`>``VY&@!AZQ<`&P`,
M[!<@.@56ZW<``@`,N8$`?>/0\<@`!,+:;MGKH;D:`-NY!`"]N>=PVKD(`!;L
M82"_`%6Y@@`=Z]8`'@`-N1H`E.M&`!L`#.Q&(#H%5NMF``(`#+F!`&WCT/'0
M``3"VF[9ZZ&Y&@#:N00`K;GG8->Y"`!)[)0@OP!5N8(`3>O9`!X`#;D:`+'K
M&0`;``SL&2`Z!5;KF0`"``RY@0"=X]#QV``$PMINV>NAN1H`U[D$`'VYYY#6
MN0@`&^RQ(+\`5;F"`!WKVP`>``VY&@"DZTL`&P`,[$L@.@56Z[L``@`,N8$`
MO>/0\>``!,+:;MGKH;D:`-:Y!`!MN>>PV;D:`'&Y"`!*[*0@OP!5N8(`3>L:
M`!L`#.O:`!X`#>P:(#H%5KD(`!?KJ@`"``SL<2"_`%6Y@0"MN>:@V[F``-&Y
MY*`;N8$`T;D:`&3C$/'H``3K1P`;``S"&H\;O-SL1R`Z!5:Y&@`9N0@`1KD:
M`!WKUP`>``WL9""_`%7K=P`"``RY@0!]N>9PVKF``-2YY'!*N8$`U+D$`)'C
M0/'P``3K%@`;``S"2H\;O-SL%B`Z!5:Y&@!+N0@`&;D:`$WKU@`>``WLD2"_
M`%7K9@`"``RY@0!MN>9@U[F``-&YY&`7N8$`T;D$`+3C$/'X``3K20`;``S"
M&H\;O-SL22`Z!5:Y&@`:N0@`2[D:`!WKV0`>``WLM""_`%7KF0`"``RY@0"=
MN>:0UKF``-2YY)!&N8$`U+D$`*'C0/(```3K&P`;``S"2H\;O-SL&R`Z!5:Y
M&@!'N0@`&KD:`$WKVP`>``WLH2"_`%7KNP`"``RY@0"]N>:PV;F``-&YY+`9
MN8$`T;D$`'3C$/((``3K2@`;``S"&H\;O-SL2B`Z!5:Y&@`6N0@`1[D:`!WK
MV@`>``WL=""_`%7KJ@`"``RY@0"MN>:@V[F``-2YY*!+N8$`U+D$`&'C0/(0
M``3K%P`;``S"2H\;O-SL%R`Z!5:Y&@!)N0@`%KD:`$WKUP`>``WL82"_`%7K
M=P`"``RY@0!]N>9PVKF``-&YY'`:N8$`T;D$`)3C$/(8``3K1@`;``S"&H\;
MO-SL1B`Z!5:Y&@`;N0@`2;D:`!WKU@`>``WLE""_`%7K9@`"``RY@0!MN>9@
MU[F``-2YY&!'N8$`U+D$`+'C0/(@``3K&0`;``S"2H\;O-SL&2`Z!5:Y&@!*
MN0@`&[D:`$WKV0`>``WLL2"_`%7KF0`"``RY@0"=N>:0UKF``-&YY)`6N8$`
MT;D$`*3C$/(H``3K2P`;``S"&H\;O-SL2R`Z!5:Y&@`7N0@`2KD:`!WKVP`>
M``WLI""_`%7KNP`"``RY@0"]N>:PV;F``-2YY+!)N00`<;F!`-3C0/(P``3"
M2H\;O-RY&@!&N1H`3;D$`&3KV@`>``WK&@`;``SL&B`Z!5:Y"``7['$@OP!5
MZT<`&P`,[$<@.@56N0@`1NQD(+\`5>NJ``(`#+F!`*VYYJ#;N8``T;GDH!NY
M@0#1XQ#R.``$PAJ/&[S<N1H`&;D:`!WKUP`>``WK=P`"``RY@0!]N>9PVKF`
M`-2YY'!*N8$`U+D$`)'C0/)```3K%@`;``S"2H\;O-SL%B`Z!5:Y&@!+N0@`
M&;D:`$WKU@`>``WLD2"_`%7K9@`"``RY@0!MN>9@U[F``-&YY&`7N8$`T;D$
M`+3C$/)(``3K20`;``S"&H\;O-SL22`Z!5:Y&@`:N0@`2[D:`!WKV0`>``WL
MM""_`%7KF0`"``RY@0"=N>:0UKF``-2YY)!&N8$`U+D$`*'C0/)0``3K&P`;
M``S"2H\;O-SL&R`Z!5:Y&@!'N0@`&KD:`$WKVP`>``WLH2"_`%7KNP`"``RY
M@0"]N>:PV;F``-&YY+`9N8$`T;D$`'3C$/)8``3K2@`;``S"&H\;O-SL2B`Z
M!5:Y&@`6N0@`1[D:`!WKV@`>``WL=""_`%7KJ@`"``RY@0"MN>:@V[F``-2Y
MY*!+N8$`U+D$`&'C0/)@``3K%P`;``S"2H\;O-SL%R`Z!5:Y&@!)N0@`%KD:
M`$WKUP`>``WL82"_`%7K=P`"``RY@0!]N>9PVKF``-&YY'`:N8$`T;D$`)3C
M$/)H``3K1@`;``S"&H\;O-SL1B`Z!5:Y&@`;N0@`2;D:`!WKU@`>``WLE""_
M`%7K9@`"``RY@0!MN>9@U[F``-2YY&!'N8$`U+D$`+'C0/)P``3K&0`;``S"
M2H\;O-SL&2`Z!5:Y&@!*N0@`&[D:`$WKV0`>``WLL2"_`%7KF0`"``RY@0"=
MN>:0UKF``-&YY)`6N8$`T;D$`*3C$/)X``3K2P`;``S"&H\;O-SL2R`Z!5:Y
M&@`7N0@`2KD:`!WKVP`>``WLI""_`%7KNP`"``RY@0"]N>:PV;F``-2YY+!)
MN8$`U.-`\H``!,)*CQN\W+D:`$:Y&@!-Z]H`'@`-N00`<>L:`!L`#.P:(#H%
M5NNJ``(`#+F!`*WCT/*(``3"VLIBP=:Y&@#9N00`G;GGH-NY"``7['$@OP!5
MN8(`'>O7`!X`#;D$`&3K1P`;``SL1R`Z!5;K=P`"``RY@0!]X]#RD``$PMK*
M8L'6N1H`V[D$`+VYYW#:N0@`1NQD(+\`5;F"`$WKU@`>``VY&@"1ZQ8`&P`,
M[!8@.@56ZV8``@`,N8$`;>/0\I@`!,+:RF+!UKD:`-JY!`"MN>=@U[D(`!GL
MD2"_`%6Y@@`=Z]D`'@`-N1H`M.M)`!L`#.Q)(#H%5NN9``(`#+F!`)WCT/*@
M``3"VLIBP=:Y&@#7N00`?;GGD-:Y"`!+[+0@OP!5N8(`3>O;`!X`#;D:`*'K
M&P`;``SL&R`Z!5;KNP`"``RY@0"]X]#RJ``$PMK*8L'6N1H`UKD$`&VYY[#9
MN0@`&NRA(+\`5;F"`!WKV@`>``VY&@!TZTH`&P`,[$H@.@56ZZH``@`,N8$`
MK>/0\K``!,+:RF+!UKD:`-FY!`"=N>>@V[D(`$?L=""_`%6Y@@!-Z]<`'@`-
MN1H`8>L7`!L`#.P7(#H%5NMW``(`#+F!`'WCT/*X``3"VLIBP=:Y&@#;N00`
MO;GG<-JY"``6[&$@OP!5N8(`'>O6`!X`#;D:`)3K1@`;``SL1B`Z!5;K9@`"
M``RY@0!MX]#RP``$PMK*8L'6N1H`VKD$`*VYYV#7N0@`2>R4(+\`5;F"`$WK
MV0`>``VY&@"QZQD`&P`,[!D@.@56ZYD``@`,N8$`G>/0\L@`!,+:RF+!UKD:
M`->Y!`!]N>>0UKD(`!OLL2"_`%6Y@@`=Z]L`'@`-N1H`I.M+`!L`#.Q+(#H%
M5NN[``(`#+F!`+WCT/+0``3"VLIBP=:Y&@#6N00`;;GGL-FY"`!*[*0@OP!5
MN8(`3>O:`!X`#;D:`''K&@`;``SL&B`Z!5;KJ@`"``RY@0"MX]#RV``$PMK*
M8L'6N1H`V;D$`)VYYZ#;N0@`%^QQ(+\`5;F"`!WKUP`>``VY&@!DZT<`&P`,
M[$<@.@56ZW<``@`,N8$`?>/0\N``!,+:RF+!UKD:`-NY!`"]N>=PVKD(`$;L
M9""_`%6Y@@!-Z]8`'@`-N1H`D>L6`!L`#.P6(#H%5NMF``(`#+F!`&WCT/+H
M``3"VLIBP=:Y&@#:N00`K;GG8->Y"``9[)$@OP!5N8(`'>O9`!X`#;D:`+3K
M20`;``SL22`Z!5;KF0`"``RY@0"=X]#R\``$PMK*8L'6N1H`U[D$`'VYYY#6
MN0@`2^RT(+\`5;F"`$WKVP`>``VY&@"AZQL`&P`,[!L@.@56Z[L``@`,N8$`
MO>/0\O@`!,+:RF+!UKD:`-:Y!`!MN>>PV;D(`!KLH2"_`%6Y@@`=Z]H`'@`-
MN1H`=.M*`!L`#.Q*(#H%5NNJ``(`#+F!`*WCT/,```3"VLIBP=:Y&@#9N00`
MG;GGH-NY&@!AN0@`1^QT(+\`5;F"`$WKUP`>``VY&@"4ZQ<`&P`,[!<@.@56
MZW<``@`,N0@`%KF!`'WL82"_`%7CT/,(``3K1@`;``S"VLIBP=;L1B`Z!5:Y
M&@#;N0@`2>R4(+\`5;D$`+VYYW#:N8(`'>O6`!X`#>MF``(`#+F!`&WCT/,0
M``3"VLIBP=:Y&@#:N00`K;GG8->Y@@!-Z]D`'@`-N1H`L>L9`!L`#.P9(#H%
M5NN9``(`#+F!`)WCT/,8``3"VLIBP=:Y&@#7N00`?;GGD-:Y&@"DN0@`&^RQ
M(+\`5;F"`!WCT/,@``2Y&@!QPMK*8L'6N1H`UNM+`!L`#+D$`&WL2R`Z!5:Y
M"`!*[*0@OP!5ZQH`&P`,[!H@.@56N0@`%^M[`!X`#<`:`````.N[``(`#+F!
M`+>YY[#9N8(`3;D(``&Y&@!DP`H`````XP`@"``DZT$`&P`,N1H`6^Q!(#H%
M5L!:`````.-0(!@`)+D(`$;C$"`@``2Y&@`TN1H`&<`Z`````.,P(```),`:
M`````.,0("``).MZ``(`#.QZ("$>5KD(`(?`B@````#C@"`0`"2R3P`0ZQ$`
M(``-LD\`$=4'\R@0**>$``7`Y?__\:OC0/.@``3K;_-@``0']`<'ZV_P,``D
MX_#_8/]Q["@`40!\Q!@``$$;XV`0```"IX0`2+D$`$+C$$```)3L%@`V`'X;
M0KD$`(*Y!`!SN00`IKD4`+3CD*````*GA``>N00`2[D$`#CC(*````3`Y?__
M[Q+L)@`B`'Y!&Y``E3T0`*=T`!NY"0"F09N0`>NJ``,`"E"@<`"Y!``IXT#Q
M$``$ZV_PT``$!_3L&/_-/7Y!0$`!I_3_PD&@H`BG]/_-IYD``*?T_^H'!^OO
M\'``)+)/`!#K$0`@``VR3P`1X_#_4/]Q03#PI-('\*@0*,#E____DK)/`!#K
M$0`@``VR3P`1U0?PJ!`HIX0`!<#E___Q(^-`\2``!.OO\2``!`?T!P?KK_!0
M`"2R3P`0X_#_4/]QZQ$`(``-LD\`$;D$`++2!_"H$"A!H/"DN00`.KD$`"O`
MY?___V#L)@`2`'RR3P`0ZQ$`(``-LD\`$=4'\*@0**>$`![`Y?__\.[C$/"D
M`!3$*```0&SK$0`#``WC$"````CC(!`(``3C(!```"3L*/_5`'Q!$!`(I_3_
M]>-`\2``!.NO\0``!`?T!P<'!P<'ZV_P,``DP-````WYX_#_4/]QLD\`$.L1
M`"``#;)/`!&Y!`"SIP@``-('\*@0*.,0,```E*<X``#`%P```#VY^Q`3X[#0
M``"(IZD``+D$`)*Y!``;03#PI+)>`*&G%/_^N0D`J\#E___^]NPH`#$`?*<(
M``"G&0``N00`,K)>`!.G%/_^N0D`$NRA`)$@9:<9``#C,;```)!",2``IQL`
M`>PV__D`?*<H``"R3P`0ZQ$`(``-LD\`$=4'\*@0*+D4`"*GA`#.P.7___!E
MQ!@``#_FXW`0```$IQD``!B!IQL``>LA``,`#>,B?_C_`J=T__?`$```2&?C
M$!```!*GA``<[#@``@#8N00`)[D4`#/K,P`#``W`Y?__[,W$&```/[[C(!``
M`"3L)@`M`'RG*/__I_3_O,`0``!(1>PH``(`V.5,$````;D4`"+K(@`#``W`
MY?__[9^Y!`!B["C_Z0!\N10`2+D$`#?K1``#``W`Y?__[:#$&```/Y'C8!``
M`"2Y%``8Q"@``#^)IQL``>,@(```!.L1``,`#4$1(`#E2!````!0@/"DN00`
M&>,@$```E.PF`$<`?KD)`!GL*@`"`-FY&``AQ(@``#]HXW#PI``4ZW<``P`-
MXW"````(P.7__^U8XR!P```D["C_H0!\XQ#PI``4XR"````$ZQ$``P`-XQ$@
M```$XR"0``"00B`0`$&0D`&YE``B["8`&@!^DCT0`*<I``#C,K```)!",A`!
MIRL``>PV__D`?*?T_S3L*/^\/7Y!$!`!I_3_L>PH_^D]?D$0$`&G]/_8XU#Q
M(``$ZV_PX``$!_4'!P<'ZW_P.``DLD\`$./P_LC_<>L1`"``#;)/`!'2!_$P
M$"CL*``E`'RY!`"BE0`@`*>$`![`Y?__Z]>Y!`""["@`%P!\07#PH+D$`"C`
MY?__[(OL)@`<`'RY!``HP.7__^TSN00`*L#E___NGK)/`!#K$0`@``VR3P`1
MU0?Q,!`HIX0`;L#E___O3T&P(!/`$```#*:G"```N00`*[)=`!*G%/_^IX3_
MTL`0```,FKD$`"NR70`2IQ3__J>$_\>Y!``:IRD``+)>`"&G%/_^N00`.Z<9
M``"R7@`3IQ3__KD)`!NY"0`J&B&G*@`"N10`(L#E___LF<`P```,=;D$`)*Y
M!`!;N00`2L#E___NS;D$`#>Y!``IP.7__^Z&["@`&?]^6!#PN*<H0`#`&P``
M\`#L$@`/8':Y!``IP.7___]DN00`*<#E___N7Z?T_W^Y!``IP.7__^Q8I_3_
M].-`\:@`!.M_\7``!`?TZZ_P4``DX_#_8/]QN00`HL2X```^4.,@L```%L#E
M___N?NPR`?@`V;D$`"K`Y?__[(;L*``.`'ZG*```N10`(N-`\1``!.NO\/``
M!`?TXR"P```6P.7__^YB6!`B$*<H0`#`&P``\`#L$@`18':G.0`"N00`*L#E
M___K41`BIRK__X@@`!^G]/_;XR"P```6P.7__^Y$6!`B$*4OH`#`&P``\`#L
M$O_*8':G]/_B!P?K[_!P`"3$&```/?WC\/]@_W'C(!```!;`Y?__[BC`4```
M"\G$2```/@;`,```"]'K[_$0``3`]/__[?D'!P<'ZV_P,``DX_#_6/]QQ+@`
M`#W:XR"P```6P&````TZP.7__^X%P.7____.XR"P```6P.7__^W\N00`5N5(
M\*```,!````)(,`P```+L<#E___K#N-`\1@`!.MO\-@`!`?TZV_P,``DLD\`
M$./P_U#]<>L1`"``#>,@\*@"<;)/`!'2!R``$"C`Y?__ZS%!L/"FN00`4L!@
M```+E<!````+E*<Y$`&Y!``KP.7__^K0["8`&?]^I[D``+)/`!#C,/"H`G'K
M$0`@``VR3P`1N00`*]4',``0**>$`$K`Y?__[??L(!``(''L)/_G`'[CH/"G
M`7&G21``N00`.KD$`"O`Y?__[&6Y!`""["3_U@!^IRH``;D4`"+`Y?__ZUFY
M!`"R["C_R@!\N10`F.PJ``>@94$9(`"Y84"A[+H`!\!E01F@`+EA0+'L@!`!
M('*Y!`!)N00`.KD$`"O`Y?__[8A!&;``D@`0`*?T_ZGC0/$@`@3K;_#@`@0'
M],#T____=`<'ZV_P,``DLD\`$./P_U#^<;D$`++K$0`@``WC(/"H`7&R3P`1
MN00`@]('(``0*,`@```+$,#E___\1J<Y`"^Y!`"2N00`*\#E___KL>PH`!\`
M?+D$`#O`(```"P'`Y?___*ZR3P`0XS#PJ`%QZQ$`(``-LD\`$;D$`"O5!S``
M$"BGA`"]P.7__^UBIP@``+D$`!NY!``HIZD``,`P```*YK)>`*&G%/_^P-``
M``JL&ZM!@/"HIZH``<#E___LZ.PH_\H`?)4`(`"YXH`M[)@`&0!\IP@``+D$
M`!*Y!``YLET`$Z<4__ZG=``,P#````J^IRD``,#E___LRJ?T_^*G"```IQD`
M`+D$`#*R7@`3IQ3__AL2N10`,>,S+___<94O,`"GA``C&AJG.`__[!/_DR!V
MX[#PH``DN00`4L!@```*EL!````+(Z<Y$`"Y!``HP.7__^F\IQ@0`*<J``'L
M(0`/P'>G]``!IQK__[D4`#%!,R``D@`P`*?T_\[$>```/&+C('```!;`Y?__
M[)#L,@'X`-FY!``HP.7__^Q8[";_I@!^XR!P```6P.7__^Q_6!`B$*4O@`#`
M&P``\`#L$O^68':G.0`!N00`*,#E___I;NPF_XP`?KD$`#C`(```"C[`Y?__
M^^NY!``HP.7__^J.N00`LJ?T_S;C0/$@`03K;_#@`00']$$0(`'C,!___Y3L
M-@`$`'X'_J<^`"^YXH`AIQL``:?T__,'!P<'!P?L*``)`'SC4"```)3L5@`)
M`'[`(```"=_`]/__ZF"Y!``RIP@``*<9``"R7@`3IQ3__N-`'___<;GI(#'L
M)``&(&7L)@`%_WRG.0`!IS<`$NPD`"Q@9.Q8_]XO?L`@```)[J?T_]OC0$__
M_W&G]/_PE2]``*>$__FYZ2`4XS!/__]QN2$`(Z<Y``&YXC`3I_0`">-`3___
M<:<7``2G]/_:E2]``*=T__>YZ2`4XS!/__]Q[",`!B!E["8`!?]\IQD``>-`
M3___<:<7``^Y"0!"ISD0`.P4``(`V>P3``S`9:<I```'_I4O0`"GA/_LI_3_
M[^OO\'``)*=+``'C\/]@_W&Y!``R[$`0`"!QP"```#P>P.7__^J3P"```#P8
MXT#Q$``$Z^_Q$``$!_0'!P<'Z^_P<``DLD\`$.L1`"``#;)/`!'C\/\P_W'`
M(```"7C2!_#($"C`$```"1G2(?"F$`#`Y?__^L/`(```"6[`Y?__^KW`(```
M"6S`Y?__^K?`(```"6O`Y?__^K'`(```"6G`Y?__^JO`(```"6O`Y?__^J7`
M(```"3W`Y?__^I_`(```"67`Y?__^IG`(```"63`Y?__^I/`(```"6/`Y?__
M^HW`(```"2K`Y?__^H?`(```"5S`Y?__^H'`(```"5O`Y?__^GO`(```"5O`
MY?__^DGL*``+`'RY!``RP"````D[P.7___JZP"````E3P.7___HX["@`"P!\
MN00`,L`@```)4<#E___ZJ<`@```)4<#E___Z)^PH`",`?+D$`#+`(```".;`
MY?__^IC`,```"5?`(```"/W`Y?__^H^R3P`0ZQ$`(``-LD\`$=4'\,@0**>$
M`";`Y?__ZTC`(```"3#`Y?__^?[L*``*`'RY!``RP"````CKI_3_UZ=)``K`
M,```"2=!(/"WP.7__^C.[";_S@!^03#PP:?T_^SC0/%```3K[_%```0']`<'
MQ!T``#L,IQ[__Z=T`##K[_!P`"3`(```",/C\/]@_W'`Y?__^<CL*``>`'SC
M$"```)#L&``8`'S`%P```#"Y`P`1ZQ$`/P`,Q!\``#KHXT#Q$``$Q"P``#KB
MZ^_Q$``$!_2G&```I_3_\<0L```ZUP?^!P<'!P<'Z^_P<``DX_#_8/]QP.7_
M_^KJP.7__^DG["@`#0!\XR`@```$XT#Q$``$Z^_Q$``$!_2G*0``I_3_]P<'
M!P<'!^MO\#``)+)/`!#C\/\@_W'K$0`@``VR3P`1N00`HM('\-@0*,`0```Z
M4M(W\*`0`$&P\*#CD+````*G=``1LD\`$.L1`"``#;)/`!'5!_#8$"BGA`!/
MP.7__^J5XR"P```$P.7___E+N00`.KD$`&+L*``'`'R5`"``IW0`"[D$`"G`
MY?__^;>GNP`(I_3_U,#E___H>.PF__D`?*<(``"Y!``:LEX`(:<4__ZY!``V
MIQD``+)>`!.G%/_^N0D`%KD)`"I!(A`"P.7__^?<P#````AYN00`@L!0```'
MX[D$`$K`Y?__Z@^Y!``XI_3_R>-`\5``!.MO\1``!`?T!P?K;_`P`"3`T```
M!XFY!`#OX_#^`/=QI^O_X&"`X`!@H.`(8,#@$&#@X!BR3P`0ZQ$`(``-LD\`
M$;D$`*+C(/'8"''2!R``$"C`$```.=S2%_"X$`#`$```.>+2+_#H$`#`$```
M.?32%_#0$`#`(```!XW`Y?__^,/L*``G`'RY!`"RE0`@`*>$`"#`Y?___SNY
M!``KP.7__^?6N00`@K)/`!#C,/'8"''K$0`@``VR3P`1N00`*-4',``0**>$
M!*C`Y?__Z>#`Y?___OWL)@#;`'Q!D/#0XQ"0```"IW0`!\"P```'Y:?T`!GC
M()````3`Y?__^(3L*`#"`'R5`"``IX0`O<#E___GGKD$`+*GFP`([+C_X@!\
MIP@``+D$`!NG*0``LEX`(:<4__ZY"0`KZR(``0`-IRL``<#E___G([D$`)*Y
M!`""XT"P``"4[$8`G@!^0;#PZ..`L````J>$`![C(+````3`Y?__^$BY!`""
M["@`G`!\E0`@`*>$`)?`Y?__^J3L*`"2`'ZY!``HP.7__^=8N00`@D&P\+CL
MA@`,`'SC<+````*GA``&E0!P`*=T`("G"```N00`&*>Y``"R7@"QIQ3__KD$
M`"FG&0``LEX`$J<4__ZY"0`9N0D`N!JQI[H$!+D4`+NY!``KP&````=DP.7_
M_^;%XY#PH``DN00`<L`P```'7,!0```&RKD$`$C`Y?__Z/6G.0'`N00`)\#E
M___HCNPF`%C_?L#E___H>-4#T``@`*>$`$_CL*````3`Y?__Z&W$&```.'KC
M8"```!2Y!`!7N00`2\`P```'-.,@$```!,#E___GZJ>)``"G]/\4I[D``*?T
M_TBY!`"RI_3_2;D$`"BY%`!$P#````<00;"P`4&`@`+`Y?__Z+"G]/]1I[L`
M"*?T_U7C(+````3`Y?__^@CL*``*`'ZY!``GP.7__^:\N00`@J>[``BG]/]D
MQ(@``#A/XR"````6P.7__^A][#(!^`#9N00`)\#E___FA1B2["8#=`!^XR"`
M```6P.7__^AK6!`B$*<H0`#`&P``\`#L$@-D8';C((```!;`Y?__Z%M88"(4
MP.7__^BV[&(#5F!VXR"````6P.7__^A-6!`B$*<H`<#`&P```?_L$@-&8':Y
M!``KP.7__^8.N00`@L`@```&F\#E___W0NPH`!4`?..PH```!,#E___F7;D$
M`#*Y!``KP.7___K2N00`LNPF``8`?..PH```!*<(``"G&0``N00`*[)>`!*G
M%/_^N0D`&^P<`$(#?KD4`"'C,K_\_W'`(```!IFR70`CIQ3__J=T`#/L&``.
M!'ZG&O_\N10`$>,1O___<94O$`"G=``EXR"@"``"IX0`(*<(``"G&0``N00`
M,K)>`!.G%/_^N0D`$NP<`!(#?>,A+_S_<<`0```&;K)=`!*G%/_^IW0`!>.P
MH`@`!,#E___]`>PF`GD`?KD$`"NG.0``P.7__^8#N00`LABB["@";`!^ITD`
M`J<Y_^Y!8/'8P.7__^4$ITD`!KD$`#:Y!``KP.7__^<;E0#QV*=T`$^50_'9
MIW0`2Y5!\=JG=`!'E4/QVZ=T`$.52/'<IW0`/Y5%\=VG=``[ITD``J<Y_\:Y
M!``KP.7__^3:ITD`*;D$`#:Y!``KP.7__^;QP!````:PP%````5;XQ#PH``D
MN00`1\`P```&"[D$`"C`Y?__YWZY!``GP.7__^<IN00`.,`@```%-\#E___V
MZ;D$`"C`Y?___.RG]/VXITD``*<Y``"Y!``KP.7__^2AP!%G12,!XQ#Q&``D
MP!_OS:N)XQ#Q(``DP!^8NMS^XQ#Q*``DP!$0,E1VXQ#Q,``DP!_#TN'PXQ#Q
M.``DN10`&N5(\4```+/!`('E2/%(``!!$/$8Y4SQD```L\$`H;/-`"BE3X``
MN00`-D&0\5#`Y?__YH?C(/"P`"18H/"T[*(`Z@!^L\T`*$%@\1C`Y?__YECC
ML/%```3CH/%(``3L&SJ_?57L00`!`-BY%``101'Q4)*`$`"Y%``D[$P!E#A^
MIQ@`0*<Y``"Y^4!!02*0`+D4`$3`Y?__Y(2Y!``FP.7__^F+ITD`.*<Y``"Y
M!``IIYD``,#E___D=$*@\8M"L/&/ZQH`&``,0A#QB.L:`!``#$(0\8GK&@`(
M``Q"$/&*ZQL`&``,0A#QC.L;`!``#$(0\8WK&P`(``Q"$/&.N00`)D&P\:^G
MJ0`4N00`:\#E___I4^,0\1@`!$(0\9[K(0`8``Q"(/&;ZR$`$``,0B#QG.LA
M``@`#$(@\9WC$/$@``1"$/&BZR$`&``,0B#QG^LA`!``#$(@\:#K(0`(``Q"
M(/&AXQ#Q*``$0A#QINLA`!@`#$(@\:/K(0`0``Q"(/&DZR$`"``,0B#QI>,0
M\3``!.LA`!@`#$(@\:="$/&JZR$`$``,0B#QJ.LA``@`#$(@\:GC$/$X``3K
M(0`8``Q"(/&KZR$`$``,0A#QKD(@\:SK(0`(``Q!$/&;0B#QK;/!`(&SS0`8
MN00`*\`P```$H>-)$```D*>[``*GFP`!P.7__^8^IZ?_[Y(`\=>G]/ZIXS#Q
M0``$XR#PM``4ZQ(``P`-N0@`$\`:`````.PQ``;`9>L!\4@`>N,0\4``).LB
M`!T`#.,@\4@`".,@\4@`).,0\9``$J>$`'M8(/"TIZ@`0!NA&2JY\L"BN00`
M*;D8`"&Y%`"Z["8`"*!E01L@`.QA``M`9>PF``K`94$;8`#L(0`%H&6G]``!
MI1^``.RQ__P@9;D$`$NY!``VP.7__^7W&!I:$/&04!#QD.P6_K!`?K/-`"I8
M$/"T&QI!NV``&*'`Y?__Z'!!$/&0L\$`X>L:``8`WNPA``$`V!*J&!*G*``!
MN?*@(5`@\+!8$/"PIQK__U`0\+"G=``FN10`2NRY``C`94$4D`#LL?^^0&7L
MN0`(H&5!%+``[)'_MD!E[$+_LTA]N00`.[D$`"G`Y?__Y:Y0H/&0I_3^:KD$
M`+:G]/_$[+D`",!EL\T`'NRQ_YQ`94$0L$"SP0#![+D`!J!E[)'_DD!EN00`
M.Z=)`$"Y!``IL\T`O*>J_\#`Y?__Y8>SS0`JP.7__^@.I_3_L*<8`#BG.0``
MN?E`04$BD`"Y%`!$I_3^?<`P```#F\`@```#3\"P```$?<#E___TT,#E___B
MI<`0```$=+D$`&+C$/"@`"3`4````QJY!`!'P#````/5N00`*,#E___E0*<Y
M`<"Y!``HP.7__^39[";]N_]^P.7__^3#U0/0`"``IW3]LJ>:``'`Y?__XGFY
M%``9N00`8N.P\*@`).,0\*``),!0```"[+D$`$?`,````ZZY!``HP.7__^42
MI_3_TL08```TK;D$`%?C0*````3`,````Z7C(!````3`Y?__Y!^G]/PU[8#Q
MX`AE[:#QZ`AE[<#Q\`AE[>#Q^`AEXT#R<`@$ZV_R,`@$!_0'!P<'!P?K?_`X
M`"3C\/]@_W'$N```-)KC(+```!;`Y?__Y,BY!`"BXR"P```6P.7__^3`T@"@
ML2"PP"````*MP.7___/#["@`"P!\E3$@`*=T``:5`"`!IX0`!<#E___Y!<08
M```T<N,@$```%L#E___DH*=9``NG20`!P#````.$P.7__^,&["8`40!\Q*@`
M`#1<XR"@```6P.7__^2*IUD``Z=)``'`,````W'`Y?__XO"Y!`"R["8`N@!\
MQ)@``#1$XR"0```6P.7__^1RIUD``Z=)``'`,````UW`Y?__XMBY!`"R["@`
M[0!\P"````(XP.7___-IN00`HNPH`,0`?.,@D```%L#E___D4N,0L!``!+D$
M`$KC,!````3`Y?__XM>G]`#.XQ`@$``$IZ@``.-P$"@`!.RZ``$`V,:]```\
MIZ>D`!G$B```,_[C((```!;`Y?__Y"RG60``N10`2KD$`#?`Y?__X;.Y!`"2
M["8`)`!\Q!T``#R+IQK__^RA_X9@=J>X``'&O0``/(&GI/]^Q!@``#/8XR`0
M```6I[H``<#E___D!+D$`#?`Y?__X+^G]/_KQ!@``#QFN10`NZ<X!`#KNP`#
M``WCNQ````3C$"````18(!`,P"L`(`0`[",`$F!VXR`0$``$IP@``+)=`"NG
M%/_^IW3_OJ>J``&G]/^;XR"````6P.7__^/0IUD``J=)``#C,)````3`Y?__
MY`:G]/_DXR"@```6P.7__^.^XQ"P$``$P$````*GXS`0```$P.7__^)"XQ"P
M$``$XQ`0```$D4`0#:>$_R_C(*```!;`Y?__XZ+C$+`0``3C,!````3`Y?__
MX4FG]/\>P.7___6PN00`HN,@D```%NRH`%\`?,#E___CB>,0L!``!+D$`$KC
M,!````3`Y?__X@ZY!``JP.7__^,YQ+@``#-"XR"P```6P.7__^-PN00`HN,@
ML```%L#E___C:*=)``'`,````E;`Y?__X%#`0````ENY!``RN00`*L#E___A
MYN,@L```%L#E___C4)(`(+'`(````1[`Y?__\E3$*P``.[GL)@`C`'S$*```
M.ZO`Y?__^4S$*P``.ZWL)@`7`'S`(````C3`Y?__X&#`Y?__XRW$.```.Y;C
M$+`0``3C0#````2G]/[7ISD!P,0H```[D<#E___BRNPH`!H1?NP2``$`V.P<
M`!0!?\08```[>KD$`%+$2```.WWC,!````3`(````A7`Y?__X##C0/$0``3K
M?_#8``0']`<'!P?KK_!0`"3C\/]@_W&Y!`"RP.7___:PP.7___:9N00`HL#E
M___X&.PH`!T`?NRX`!H`?)4`L`"GA``5P#````%#N00`*L#E___A(NRB``M@
M9+D$`"OKK_#P``3`]/__\X?C0/$0``3KK_#P``0']`<'Z[_P6``DX_#_8/]Q
MP+```#""XQ"P```$[!8`"O]\XT#Q$``$Z[_P^``$!_0-X>.PO_C_<:?T_^_K
M[_!P`"3C\/]@_W'C0/$0``3K[_$0``0']`<'!P<'!^OO\'``)+D$``^G^_]@
MXP#P```DP.7__^2.Z^_Q$``$!_X``````````````````%]?14Y67U!!4E]#
M3$5!3E]?("`@("`@("`@("`@("`@```````````````1`````!__________
M<&5R;'AS:2YC`````````"X`+BX``"5S+R5S`$1Y;F%,;V%D97(Z.F)O;W1?
M1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5```97AE`"]P<F]C+R5I
M+R5S`%!!4E]414U0``!005)?4%)/1TY!344``#H`+P!015),-4Q)0@``4$52
M3$Q)0@!015),-4]05```4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-0
M05=.140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`4$%27T%21T,`
M`%!!4E]!4D=67S```%!!4E]'3$]"04Q?1$5"54<``%!!4E]'3$]"04Q?5$U0
M1$E2`%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,
M14%.``!005)?0TQ%04X]```Q`$Q)0E!!5$@`3$E"4D%265]0051(``!$64Q$
M7TQ)0E)!4EE?4$%42`!32$Q)0E]0051(``!365-414T``"4P,G@``'!A<BT`
M`"5S)7,E<R5S```E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*``!P87)L```N<&%R```E<R5S8V%C
M:&4M)7,E<P``)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S```E<SH@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M
M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*```O=&UP``!414U0
M1$E2`%1-4`!54T52``!54T523D%-10``05)'5@``&`!P97)L```P`%!!4CHZ
M4&%C:V5R.CI615)324].```Q+C`S-@!5;F%B;&4@=&\@8W)E871E(&-A8VAE
M(&1I<F5C=&]R>0``)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``+64``"TM``!E=F%L
M("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@
M(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?
M<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@
M>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM
M>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP
M*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&
M:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U
M;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@
M)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE
M=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@
M1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G
M+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*
M>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E
M;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS
M;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I
M;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@
M)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<[
M"F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A
M8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP
M+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/
M3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"![
M"E]P87)?:6YI=%]E;G8H*3L*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!]
M(&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PI`05)'5B`](&UA<"`D14Y6>R)0
M05)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PHD,"`]
M("1%3E9[4$%27T%21U9?,'T["GT*96QS92!["F9O<B`H:V5Y<R`E14Y6*2![
M"F1E;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["GT*?0IM>2`D<75I
M970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@
M("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N
M97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3
M,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A
M<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L
M("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O
M9VYA;64@;W(@;&%S=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US("1P<F]G;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]
M("TQ.PIW:&EL92`H,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^
M("1S:7IE.PIS965K(%]&2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@
M9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E860@
M7T9(+"`D8G5F+"`D;V9F<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P
M<F]G;F%M92(Z("0A72!U;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@
M/2!R:6YD97@H)&)U9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X]
M(#`@?'P@)&]F9G-E="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R
M-#L*)&]F9G-E="`J/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F
M9G-E="`M/2`D:61X("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D
M(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").
M(BP@)&)U9BDL(#(["G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H
M=&5L;"!?1D@I("T@-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@
M97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U
M=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R
M8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@
M.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_
M.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?
M1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT
M*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I
M;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64[
M"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M
M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E
M9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP
M9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)
M0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L
M;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@
M/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA
M;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS
M=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@
M)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E("1R
M97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H
M("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L
M95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?;&ES
M='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.0WLD
M;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%
M3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN
M;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D
M9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@
M/2!?=&5M<&9I;&4H(B1F:6QE;F%M92T^>V-R8WTN<&TB+"`D9FEL96YA;64M
M/GMB=69]*3L*;W!E;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B
M8V%N)W0@<F5A9"`D9FEL96YA;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U
M<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F
M:6YD("1M;V1U;&4A7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*
M<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE
M(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)
M3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@
M*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE
M.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O
M<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P
M-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R
M9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*
M9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%
M(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S
M("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP
M72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M
M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U
M;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII
M9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`
M05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L
M<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*
M=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S
M5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D
M7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@
M)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF
M("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@
M97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G
M*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L
M;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@
M)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*
M?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@
M>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER
M92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!
M4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET
M.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T
M*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN
M960@)'!A<BD@>PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R
M-"D["F]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN
M9"`G)'!A<B<Z("0A(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ
M1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I("D*;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY
M("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O
M;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS
M.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ
M("@N*RDD+VUG.PI]"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P
M87(I('L*;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*
M8FEN;6]D92A005(I.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N
M;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T
M*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/
M7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/
M7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O
M(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*
M<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF
M("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\
M7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*
M?0IF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@
M/2`D96YV>R1K97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A
M;"`]?B`O7ELG(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D
M:V5Y*2`N(")?7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(]
M)'9A;"(["B1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E
M="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*
M?0HD9F@M/G!R:6YT*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L
M92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY
M($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE
M("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP
M?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`
M24Y#.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z
M.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@
M/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E
M86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF
M;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I
M9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA
M;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO
M72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ
M.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D
M,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N
M86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN
M97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT
M7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE
M(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N
M=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U
M9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A
M;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@
M/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^
M;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ
M1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D
M9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D[
M"B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N
M9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E
M<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA
M;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI
M*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL
M94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C
M86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT
M:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@
M?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M
M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!
M.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@
M;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O
M=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E
M;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D
M9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X
M(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H95]N86UE("X]
M(")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M
M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D[
M"B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@
M,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T
M87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN
M9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E
M;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#
M86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`[
M"B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%2
M7U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*
M9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I
M9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE
M;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M
M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH
M/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*
M;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ
M4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D[
M"FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP
M<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M
M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D[
M"GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T
M;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@
M97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P
M(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP
M87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@
M<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P
M(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE
M*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE
M+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N
M86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T
M:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D
M:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER
M92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR
M97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S
M.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@
M17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R
M=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I
M<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF
M:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$
M:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,[
M"F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!]
M.PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I
M<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I
M93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)
M3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U
M=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P
M87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM
M87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%
M35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL
M97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*
M;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T
M<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS
M,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA
M;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P
M=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@
M)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?
M+V<["FUY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N
M=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PII9B`H(21%3E9[4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H
M)'!R;V=N86UE*2E;.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M
M92D["G-E96L@)&9H+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V
M.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*
M<WES<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E
M('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E
M<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI3
M2$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO
M;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H
M)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N
M,SDG*2!["B1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X
M*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G
M;F%M92(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC
M;&]S92@D9F@I.PI]"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A
M8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*
M?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM0
M05)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA
M<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%
M3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@
M*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@
M/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*
M;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G
M/B<L("1T96UP;F%M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M93H@
M)"$B.PIB:6YM;V1E("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@
M)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4[
M"G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP
M;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M
M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM0
M05)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD
M<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X
M*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE
M(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R
M(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF
M("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US
M("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P
M<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H
M(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6
M>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D
M9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D
M96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O
M9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T
M*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS
M=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!
M4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E
M;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_
M($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@
M5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N
M86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#
M;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M
M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!
M3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])
M3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!
M3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE
M=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,
M14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,
M3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*
M?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@
M("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!
M4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,
M14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L
M96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L
M=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U
M<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<
M;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R![
M"G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P
M("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E
M>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O
M<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI
M9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R
M9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D
M<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S
M<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@
M:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`
M.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@
M:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@````$;`SL`
M``"X````%O__A70```4$__^)[````-3__Z'T```!%/__HJP```%4__^C!```
M`73__Z.D```!I/__IA0```'D__^G?````AS__Z@L```"3/__J&P```)L__^H
MS````JS__ZGD```"[/__J>P```,$__^K]````T3__ZP<```#7/__K4P```.$
M__^N_````ZS__Z]T```#W/__K[0```0$__^PM```!$3__[KL```$C/__OJP`
M``3$````%``````!>E(``7@.`1L,#Z`!````````/````!S__XD0```8!@!8
MA@Z'#8@,B0N*"HL)C`B-!XX&CP5&#M`'`Q?FS\[-S,O*R<C'Q@Z@`0``````
M`````#P```!<__^@V````+8`1H8.APV(#(D+B@J+"8P(C0>.!H\%1@[``@**
M"L_.S<S+RLG(Q\8.H`%""P`````````<````G/__H5````!6`%2.!H\%1@[0
M`GK/S@Z@`0```"P```"\__^AB````)H`2HH*BPF,"(T'C@:/!48.T`("B,_.
MS<S+R@Z@`0```````#P```#L__^A^````FP`1H8.APV(#(D+B@J+"8P(C0>.
M!H\%3`[0`@,"6,_.S<S+RLG(Q\8.H`$````````````T```!+/__I"@```%H
M`$J'#8@,B0N*"HL)C`B-!XX&CP5&#M@#`P%6S\[-S,O*R<C'#J`!`````"P`
M``%D__^E6````*X`1HH*BPF,"(T'C@:/!48.P`("0`K/SLW,R\H.H`%""P``
M`!P```&4__^EV````#P`3(X&CP5&#L`"9,_.#J`!````/````;3__Z7X````
M8`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#L@"`E+/SLW,R\K)R,?&#J`!````
M`````````#P```'T__^F&````1@`2H8.APV(#(D+B@J+"8P(C0>.!H\%1@[0
M0@,!!L_.S<S+RLG(Q\8.H`$````````````4```"-/__IO`````&````````
M```````\```"3/__IN````((`$J&#H<-B`R)"XH*BPF,"(T'C@:/!48.T"(#
M`?;/SLW,R\K)R,?&#J`!````````````%````HS__ZBH````(@``````````
M````)````J3__ZBX```!+``"_(X&CP5&#L`":,_.#J`!`````````````"0`
M``+,__^IP````:X`5(X&CP5&#O`"`P&2S\X.H`$````````````L```"]/__
MJT@```!R`%J.!H\%1@[``@)`"L_.#J`!0@M(#J`!SL\````````````D```#
M)/__JY`````Z`$:.!H\%1@[``F0*S\X.H`%""P``````````/````TS__ZNH
M````_@!*A@Z'#8@,B0N*"HL)C`B-!XX&CP5&#H`#`NS/SLW,R\K)R,?&#J`!
M`````````````$0```.,__^L:```"C(`1H8.APV(#(D+B@J+"8P(C0>.!H\%
M4`Z@A0)4F!B9%YH6FQ4#"@;/SLW,R\K)R,?&V]K9V`Z@`0```#0```/4__^V
M6````[P`1H<-B`R)"XH*BPF,"(T'C@:/!48.P`(#`Z[/SLW,R\K)R,<.H`$`
M````/```!`S__[G@````;@!&B@J+"8P(C0>.!H\%1@[``@)."L_.S<S+R@Z@
M`48+3,_.S<S+R@Z@`0```````````#P```1,__^`:````DP`1H8.APV(#(D+
MB@J+"8P(C0>.!H\%3`[8`@,"$`K/SLW,R\K)R,?&#J`!0@L`````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````/______
M____``````````#__________P```````````````````````````````0``
M```````!``````````$````````"U0`````````/`````````V,`````````
M#````````!DX``````````T```````!;``````!O__[U`````````A@`````
M````!0````````P(``````````8````````"V``````````*````````!&``
M````````"P`````````8`````````!4````````````````````#````````
MO8```````````@````````6@`````````!0`````````!P`````````7````
M````$Y@`````````!P```````!!H``````````@````````#,``````````)
M`````````!@`````````&````````````````&____L`````"````0````!O
M___Y`````````!0`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````+O@`````````````````````````````!F.````````&:X`````
M```9S@```````!GN````````&@X````````:+@```````!I.````````&FX`
M```````:C@```````!JN````````&LX````````:[@```````!L.````````
M&RX````````;3@```````!MN````````&XX````````;K@```````!O.````
M````&^X````````<#@```````!PN````````'$X````````<;@```````!R.
M````````'*X````````<S@```````!SN````````'0X````````=+@``````
M`!U.````````'6X````````=C@```````!VN````````'<X````````=[@``
M`````!X.````````'BX````````>3@```````!YN````````'HX````````>
MK@```````![.````````'NX````````?#@```````!\N````````'TX`````
M```?;@```````!^.````````'ZX````````?S@```````!_N````````(`X`
M```````@+@```````"!.````````(&X````````@C@```````""N````````
M(,X````````@[@```````"$``````````````````````````````%L`````
M````````````````````````````````````&3@`````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#``````````%S.````````7+8```````!<O@``
M`````%SD````````7,P```````!<W@``````````````````7=0```````!;
M>```````````````````7'H```````!<?@```````%W:````````6\H`````
M``!=X@``````````````````7>8```````!=[```````````_____P``````
M``````!>CD=#0SH@*$%L<&EN92`V+C,N,"D@-BXS+C```"YS:'-T<G1A8@`N
M:6YT97)P`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;&$N9'EN`"YR
M96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H
M9'(`+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`+FIC<@`N9'EN86UI8P`N9V]T
M`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````````````````
M````````````````````````````````````````````````````````````
M``````L````!``````````(````````"``````````(``````````!@`````
M```````````````!```````````````3;___]@`````````"`````````A@`
M```````"&`````````"\`````P``````````````"```````````````'0``
M``L``````````@````````+8`````````M@````````),`````0````"````
M``````@`````````&````"4````#``````````(````````,"`````````P(
M````````!&`````````````````````!```````````````M````!```````
M```"````````$&@````````0:`````````,P`````P``````````````"```
M```````8````-P````0`````````0@```````!.8````````$Y@````````%
MH`````,````2``````````@`````````&````$$````!``````````8`````
M```9.````````!DX`````````"@````````````````````"````````````
M```\`````0`````````&````````&6`````````98`````````>@````````
M````````````!``````````@````1P````$`````````!@```````"$`````
M````(0`````````Z``````````````````````@``````````````$T````!
M``````````8```````!;`````````%L``````````"(`````````````````
M```"``````````````!3`````0`````````"````````6R@```````!;*```
M`````$!B````````````````````"```````````````6P````$`````````
M`@```````)N,````````FXP`````````O`````````````````````0`````
M`````````&D````!``````````(```````"<2````````)Q(````````!(P`
M```````````````````(``````````````!S`````0`````````#````````
MN[@```````"KN``````````0````````````````````"```````````````
M>@````$``````````P```````+O(````````J\@`````````$```````````
M``````````@``````````````($````!``````````,```````"[V```````
M`*O8``````````@````````````````````(``````````````"&````!@``
M```````#````````N^````````"KX`````````&@````!```````````````
M"``````````0````CP````$``````````P```````+V`````````K8``````
M```"@`````````````````````@`````````"````)0````!``````````,`
M``````#``````````+```````````+`````````````````````(````````
M``````":````"``````````#````````P+````````"PL````````!!H````
M````````````````"```````````````GP````$`````````,```````````
M````````L+``````````&@````````````````````$``````````0````$`
M```#`````````````````````````````+#*`````````*@`````````````
.```````!````````````
